# Cipher Tool for WSO2 Cloud Deployments

This is a GitHub Repository for hosting cloud based cipher tool implementation for
[WSO2 Carbon Secure Vault](https://docs.wso2.com/display/ADMIN44x/Carbon+Secure+Vault+Implementation).

## Azure Key Vault based Cipher Tool

This is a cloud based cipher tool implementation for WSO2 Carbon Secure Vault integrated with
[Azure Key Vault](https://docs.microsoft.com/en-us/azure/key-vault/general/basic-concepts) used for
the storage of

- Plain text secrets used as the source for encryption

- Asymmetric key pair used for encryption

- Encrypted secrets

![Azure Key Vault based Cipher Tool](azure-kv-cipher-tool.png)

### Building from source

#### Prerequisites

- [Git client](https://git-scm.com/book/en/v2/Getting-Started-Installing-Git)

- **Java Development Kit (JDK)** version 8

    Required for building the artifact from source and executing the tool

- **Apache Maven**

    - Required for building the artifact from source
    
    - Tested and verified with version `3.5.0`

- Two Azure Key Vault instances

    - An admin Azure Key Vault to host the plain text secrets to be encrypted and the asymmetric
      key pair used for encryption of the secrets
    
    - A separate Azure Key Vault to host the encrypted secrets (accessible by the product workloads)

- An Azure Active Directory Service Principal with the following permissions to aforementioned
  Azure Key Vault instances.
  
    - Admin Azure Key Vault
    
      Secrets - Permission for `Get` action
      
      Certificates - Permission for `Get` action
    
    - Deployment Azure Key Vault
    
      Secrets - Permission for `Set` action

#### Steps

1. Clone this Git Repository.

   ```
   git clone https://github.com/wso2-enterprise/cloud-cipher-tool.git
   ```
   
2. Once cloned, move to the Git Repository root and execute a Maven build.

   ```
   mvn clean install
   ```

3. Execute the cipher tool.

   ```
   java -Dorg.wso2.cloud.vault.source.name="<ADMIN_KEY_VAULT>" -Dorg.wso2.cloud.vault.target.name="<DEPLOYMENT_KEY_VAULT>" -Dorg.wso2.cloud.vault.encryption.key="<CERTIFICATE_OBJECT_FOR_ENCRYPTION>" -Dorg.wso2.cloud.vault.sp.id="<AAD_SP_APP_ID>" -Dorg.wso2.cloud.vault.sp.key="<AAD_SP_CLIENT_SECRET>" -Dorg.wso2.cloud.vault.tenant.id="<AAD_SP_TENANT_ID>" -Dorg.wso2.cloud.secrets.input="<FS_ABSOLUTE_PATH_FOR_INPUT_SECRETS_JSON>" -jar cloud-cipher-tool-*.jar
   ```

#### Input System Properties

| System Property Key                     | Description                                                                                       |
|-----------------------------------------|---------------------------------------------------------------------------------------------------|
| `org.wso2.cloud.vault.source.name`      | Name of the admin Azure Key Vault                                                                 |
| `org.wso2.cloud.vault.target.name`      | Name of the deployment Azure Key Vault                                                            |
| `org.wso2.cloud.vault.encryption.key`   | Name of the Key Vault Certificate object of which the public key is used for encryption           |
| `org.wso2.cloud.vault.sp.id`            | Application ID of the Azure Active Directory Service Principal                                    |
| `org.wso2.cloud.vault.sp.key`           | Client secret of the Azure Active Directory Service Principal                                     |
| `org.wso2.cloud.vault.tenant.id`        | Tenant ID of the Azure Active Directory Service Principal                                         |
| `org.wso2.cloud.secrets.input`          | Absolute file system path to the JSON file containing Key Vault Secret identifier-version details |
| `org.wso2.cloud.cipher.transformation`  | Algorithm name used for encryption/transformation                                                 |
