/*
 * Copyright (c) 2021, WSO2 Inc. (http://www.wso2.org) All Rights Reserved.
 */

package org.wso2.cloud.secrets;

import com.azure.security.keyvault.certificates.CertificateClient;
import com.azure.security.keyvault.secrets.SecretClient;
import org.wso2.cloud.secrets.model.InputSecretIdentifiers;
import org.wso2.cloud.secrets.model.Secret;
import org.wso2.cloud.secrets.utils.AzureKeyVaultUtils;
import org.wso2.cloud.secrets.utils.Constants;
import org.wso2.cloud.secrets.utils.EncryptionUtils;

import java.util.List;

/**
 * This Java Class implements the main function for executing password encryption.
 *
 * @since 1.0.0
 */
public class CipherTool {

    public static void main(String... args) {

        EncryptionUtils.validateSystemPropertyBasedInput();

        InputSecretIdentifiers inputSecretIdentifiers = EncryptionUtils.loadInputSecrets();

        SecretClient sourceKeyVaultSecretClient = AzureKeyVaultUtils.createSecretClient(
                System.getProperty(Constants.SOURCE_AZURE_KEY_VAULT_NAME_SYS_PROPERTY_KEY));

        List<Secret> secrets =
                AzureKeyVaultUtils.retrievePlainTextSecrets(inputSecretIdentifiers, sourceKeyVaultSecretClient);

        CertificateClient sourceKeyVaultCertificateClient = AzureKeyVaultUtils.createCertificateClient(
                System.getProperty(Constants.SOURCE_AZURE_KEY_VAULT_NAME_SYS_PROPERTY_KEY));

        String certificateString = AzureKeyVaultUtils.getPublicKeyForEncryption(sourceKeyVaultCertificateClient);

        EncryptionUtils.encryptPlainTextSecretsUsingCertString(secrets, certificateString);

        SecretClient targetKeyVaultSecretClient = AzureKeyVaultUtils.createSecretClient(
                System.getProperty(Constants.TARGET_AZURE_KEY_VAULT_NAME_SYS_PROPERTY_KEY));

        AzureKeyVaultUtils.pushSecretsToAzureKeyVault(secrets, targetKeyVaultSecretClient);
    }
}
